@@ -15,111 +15,91 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
+from typing import Any, Optional
+
 import os
+import hashlib
 import random
+import threading
 import time
-from ._compat import long, binary_type
-try:
-    import threading as _threading
-except ImportError:
-    import dummy_threading as _threading
 
 
-class EntropyPool(object):
+class EntropyPool:
 
     # This is an entropy pool for Python implementations that do not
     # have a working SystemRandom.  I'm not sure there are any, but
     # leaving this code doesn't hurt anything as the library code
     # is used if present.
 
-    def __init__(self, seed=None):
+    def __init__(self, seed: Optional[bytes] = None):
         self.pool_index = 0
-        self.digest = None
+        self.digest: Optional[bytearray] = None
         self.next_byte = 0
-        self.lock = _threading.Lock()
-        try:
-            import hashlib
-            self.hash = hashlib.sha1()
-            self.hash_len = 20
-        except ImportError:
-            try:
-                import sha
-                self.hash = sha.new()
-                self.hash_len = 20
-            except ImportError:
-                import md5  # pylint: disable=import-error
-                self.hash = md5.new()
-                self.hash_len = 16
-        self.pool = bytearray(b'\0' * self.hash_len)
+        self.lock = threading.Lock()
+        self.hash = hashlib.sha1()
+        self.hash_len = 20
+        self.pool = bytearray(b"\0" * self.hash_len)
         if seed is not None:
-            self.stir(bytearray(seed))
+            self._stir(seed)
             self.seeded = True
             self.seed_pid = os.getpid()
         else:
             self.seeded = False
             self.seed_pid = 0
 
-    def stir(self, entropy, already_locked=False):
-        if not already_locked:
-            self.lock.acquire()
-        try:
-            for c in entropy:
-                if self.pool_index == self.hash_len:
-                    self.pool_index = 0
-                b = c & 0xff
-                self.pool[self.pool_index] ^= b
-                self.pool_index += 1
-        finally:
-            if not already_locked:
-                self.lock.release()
+    def _stir(self, entropy: bytes) -> None:
+        for c in entropy:
+            if self.pool_index == self.hash_len:
+                self.pool_index = 0
+            b = c & 0xFF
+            self.pool[self.pool_index] ^= b
+            self.pool_index += 1
 
-    def _maybe_seed(self):
+    def stir(self, entropy: bytes) -> None:
+        with self.lock:
+            self._stir(entropy)
+
+    def _maybe_seed(self) -> None:
         if not self.seeded or self.seed_pid != os.getpid():
             try:
                 seed = os.urandom(16)
-            except Exception:
+            except Exception:  # pragma: no cover
                 try:
-                    r = open('/dev/urandom', 'rb', 0)
-                    try:
+                    with open("/dev/urandom", "rb", 0) as r:
                         seed = r.read(16)
-                    finally:
-                        r.close()
                 except Exception:
-                    seed = str(time.time())
+                    seed = str(time.time()).encode()
             self.seeded = True
             self.seed_pid = os.getpid()
             self.digest = None
             seed = bytearray(seed)
-            self.stir(seed, True)
+            self._stir(seed)
 
-    def random_8(self):
-        self.lock.acquire()
-        try:
+    def random_8(self) -> int:
+        with self.lock:
             self._maybe_seed()
             if self.digest is None or self.next_byte == self.hash_len:
-                self.hash.update(binary_type(self.pool))
+                self.hash.update(bytes(self.pool))
                 self.digest = bytearray(self.hash.digest())
-                self.stir(self.digest, True)
+                self._stir(self.digest)
                 self.next_byte = 0
             value = self.digest[self.next_byte]
             self.next_byte += 1
-        finally:
-            self.lock.release()
         return value
 
-    def random_16(self):
+    def random_16(self) -> int:
         return self.random_8() * 256 + self.random_8()
 
-    def random_32(self):
+    def random_32(self) -> int:
         return self.random_16() * 65536 + self.random_16()
 
-    def random_between(self, first, last):
+    def random_between(self, first: int, last: int) -> int:
         size = last - first + 1
-        if size > long(4294967296):
-            raise ValueError('too big')
+        if size > 4294967296:
+            raise ValueError("too big")
         if size > 65536:
             rand = self.random_32
-            max = long(4294967295)
+            max = 4294967295
         elif size > 256:
             rand = self.random_16
             max = 65535
@@ -128,20 +108,24 @@ class EntropyPool(object):
             max = 255
         return first + size * rand() // (max + 1)
 
+
 pool = EntropyPool()
 
+system_random: Optional[Any]
 try:
     system_random = random.SystemRandom()
-except Exception:
+except Exception:  # pragma: no cover
     system_random = None
 
-def random_16():
+
+def random_16() -> int:
     if system_random is not None:
         return system_random.randrange(0, 65536)
     else:
         return pool.random_16()
 
-def between(first, last):
+
+def between(first: int, last: int) -> int:
     if system_random is not None:
         return system_random.randrange(first, last + 1)
     else:
