@@ -1,4 +1,6 @@
-# Copyright (C) 2003, 2004 Nominum, Inc.
+# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
+
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,10 +15,11 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: RT.py,v 1.6 2004/03/19 00:17:27 halley Exp $
-
 import dns.rdtypes.mxbase
+import dns.immutable
+
+
+@dns.immutable.immutable
+class RT(dns.rdtypes.mxbase.UncompressedDowncasingMX):
 
-class RT(dns.rdtypes.mxbase.UncompressedMX):
     """RT record"""
-    pass
