@@ -17,12 +17,15 @@
 
 """A place to store TSIG keys."""
 
+from typing import Any, Dict
+
 import base64
 
 import dns.name
+import dns.tsig
 
 
-def from_text(textring):
+def from_text(textring: Dict[str, Any]) -> Dict[dns.name.Name, dns.tsig.Key]:
     """Convert a dictionary containing (textual DNS name, base64 secret)
     pairs into a binary keyring which has (dns.name.Name, bytes) pairs, or
     a dictionary containing (textual DNS name, (algorithm, base64 secret))
@@ -31,16 +34,16 @@ def from_text(textring):
 
     keyring = {}
     for (name, value) in textring.items():
-        name = dns.name.from_text(name)
+        kname = dns.name.from_text(name)
         if isinstance(value, str):
-            keyring[name] = dns.tsig.Key(name, value).secret
+            keyring[kname] = dns.tsig.Key(kname, value).secret
         else:
             (algorithm, secret) = value
-            keyring[name] = dns.tsig.Key(name, secret, algorithm)
+            keyring[kname] = dns.tsig.Key(kname, secret, algorithm)
     return keyring
 
 
-def to_text(keyring):
+def to_text(keyring: Dict[dns.name.Name, Any]) -> Dict[str, Any]:
     """Convert a dictionary containing (dns.name.Name, dns.tsig.Key) pairs
     into a text keyring which has (textual DNS name, (textual algorithm,
     base64 secret)) pairs, or a dictionary containing (dns.name.Name, bytes)
@@ -48,12 +51,19 @@ def to_text(keyring):
     @rtype: dict"""
 
     textring = {}
+
     def b64encode(secret):
         return base64.encodebytes(secret).decode().rstrip()
+
     for (name, key) in keyring.items():
-        name = name.to_text()
+        tname = name.to_text()
         if isinstance(key, bytes):
-            textring[name] = b64encode(key)
+            textring[tname] = b64encode(key)
         else:
-            textring[name] = (key.algorithm.to_text(), b64encode(key.secret))
+            if isinstance(key.secret, bytes):
+                text_secret = b64encode(key.secret)
+            else:
+                text_secret = str(key.secret)
+
+            textring[tname] = (key.algorithm.to_text(), text_secret)
     return textring
