@@ -35,17 +35,15 @@ import dns.tsigkeyring
 # Replace the keyname and secret with appropriate values for your
 # configuration.
 #
-keyring = dns.tsigkeyring.from_text({
-    'keyname.' : 'NjHwPsMKjdN++dOfE5iAiQ=='
-    })
+keyring = dns.tsigkeyring.from_text({"keyname.": "NjHwPsMKjdN++dOfE5iAiQ=="})
 
 #
 # Replace "example." with your domain, and "host" with your hostname.
 #
-update = dns.update.Update('example.', keyring=keyring)
-update.replace('host', 300, 'A', sys.argv[1])
+update = dns.update.Update("example.", keyring=keyring)
+update.replace("host", 300, "A", sys.argv[1])
 
 #
 # Replace "10.0.0.1" with the IP address of your master server.
 #
-response = dns.query.tcp(update, '10.0.0.1', timeout=10)
+response = dns.query.tcp(update, "10.0.0.1", timeout=10)
